

"use client"

import React from 'react';
import Image from 'next/image';
import { useEffect, useState } from 'react';
import { getWithToken, getApiData, getDownloadPdfWithToken } from '@/Helper/common';
import jsPDF from 'jspdf';
import html2canvas from 'html2canvas';
import { Button } from "@/components/ui/button";
import { Download } from "lucide-react";
import Link from 'next/link';
import { useTranslations } from "next-intl";

const Certificate = () => {
    const lang = useTranslations("Invoice");
    const [userKycData, setKycData] = useState({});
    const [mainUserData, setMainUserData] = useState({});
    const [createdAt, setCreatedAt] = useState('');
    const [domain, setDomain] = useState('');
    const [business, setBusiness] = useState('');
    const [data, setData] = useState({});

    useEffect(() => {
        fetchKycData();
    }, []);

    const fetchData = async (id) => {
        try {

            const apiResData = await getApiData(`theme-setting/get-single/${id}`);
            if (apiResData.error === false) {
                setData(apiResData.result);
            } else {
                setData("")
            }
        } catch (error) {
            console.error("Error fetching theme:", error);
        }
    };

    var apiCall = true;

    const fetchKycData = async () => {
        try {

            if (apiCall) {

                apiCall = false;

                const apiResDataLogin = await getWithToken(`get-kyc-details`);
                console.log(apiResDataLogin);
                if (apiResDataLogin.error === false) {

                    setMainUserData(apiResDataLogin?.data);
                    setKycData(apiResDataLogin?.userData);
                    setCreatedAt(apiResDataLogin?.userData?.created);
                    setBusiness(apiResDataLogin?.data?.business_name);
                    setDomain(apiResDataLogin?.userData.designation_id > 2 ? apiResDataLogin?.apiStoreData?.domain : apiResDataLogin?.userData?.domain);
                    await fetchData(apiResDataLogin?.userData?.store_id);
                    //console.log(apiResDataLogin?.userData);
                }
            }

        } catch (error) {
            console.error("Error fetching data:", error);
        }
    };

    const downloadPdf = async (e) => {

        const apiResDataLogin = await getDownloadPdfWithToken(`download-certificate`);
        console.log(apiResDataLogin);

        // e.preventDefault();
        // const capture = document.querySelector('.my-certificate');

        // try {
        //     const canvas = await html2canvas(capture, { scale: 1, backgroundColor: null });

        //     const imgData = canvas.toDataURL("image/jpeg"); // Using JPEG format
        //     const imgWidth = 300; // Adjust this as needed
        //     const imgHeight = (canvas.height * imgWidth) / canvas.width;

        //     const doc = new jsPDF('l', 'mm', 'a4');

        //     // Add image to PDF
        //     doc.addImage(imgData, 'JPEG', 0, 0, imgWidth, imgHeight);
        //     doc.save('Tapir-certificate.pdf');

        // } catch (error) {
        //     console.error("Failed to load logo:", error);
        // }
    };


    const expiryDate = () => {
        const today = new Date();
        const nextYear = new Date(today);
        nextYear.setFullYear(today.getFullYear() + 1);

        const day = String(nextYear.getDate()).padStart(2, '0');
        const month = String(nextYear.getMonth() + 1).padStart(2, '0');
        const year = String(nextYear.getFullYear()).slice(-2);
        return `${day}-${month}-${year}`;
    }

    return (
        <div className='relative'>
            <div class="flex justify-end mb-5">
                <Button onClick={downloadPdf} asChild variant="outline" className="text-lg font-semibold text-primary-500 ">
                    <Link href="#">
                        <Download className="w-3.5 h-3.5 mr-1.5" />
                        <span className='font-bold'>{lang("Download PDF")}</span>
                    </Link>
                </Button>
            </div>
            <div className="my-certificate container bg-white p-4 md:p-6" style={{ height: "auto" }}>
                <div className="relative border-4 border-yellow-200 h-full p-4">
                    <div className="border-2 border-yellow-200 h-full p-6">
                        {/* Header Section */}
                        <div className='flex  w-full'>
                            <div className="flex-shrink-0 text-center mb-4 md:mb-0 md:mr-6 self-start">
                                <div className="my-certificate" style={{ width: '120px', height: '120px' }}>
                                    <img src="/certificate-batch.png" alt="Certificate Batch" style={{ width: '100%', height: 'auto' }} />
                                </div>
                            </div>
                            {/* Certificate Title */}
                            <div className="text-center w-4/5">
                                <div className="tracking-wider text-3xl md:text-5xl lg:text-6xl mb-2">
                                    CERTIFICATE
                                </div>
                                <div className="tracking-wider text-xl md:text-2xl lg:text-3xl mb-2">
                                    OF AUTHORIZATION
                                </div>
                                <div className="tracking-wider text-lg md:text-xl lg:text-2xl">
                                    THIS CERTIFICATE IS PRESENTED TO
                                </div>
                            </div>
                        </div>
                        {/* Body Section */}
                        <div className="text-black text-center mt-8 flex flex-col w-full items-center justify-center">
                            <div className="text-lg md:text-xl lg:text-xl mb-4 text-center w-full">
                                This is to certify that
                            </div>
                            <div className="text-lg md:text-xl lg:text-2xl font-bold w-full">
                                Miss/Mrs. {userKycData.first_name} {userKycData.last_name} ({business})
                            </div>
                            <div className="mt-2 mb-4 w-full flex justify-center">
                                <div className='border-b-2 border-dotted w-10/12 border-black'></div>
                            </div>
                            <div className="text-center w-full">
                                <div className="flex flex-col md:flex-row justify-center items-center text-lg md:text-xl lg:text-2xl">
                                    <span>is appointed as the customer service point of</span>
                                    <span className="ml-2 font-bold">{domain}</span>
                                </div>
                                <div className="mt-2 mb-4 w-full flex justify-center">
                                    <div className='border-b-2 border-dotted w-9/12 border-black'></div>
                                </div>
                                <div className="mt-4 font-bold text-lg md:text-xl ">
                                    {mainUserData.business_address} {mainUserData.business_city}, {mainUserData.business_state} - {mainUserData.business_pincode}
                                </div>
                                <div className="mt-2 mb-4 w-full flex justify-center">
                                    <div className='border-b-2 border-dotted w-9/12 border-black'></div>
                                </div>
                            </div>
                        </div>

                        {/* Footer Section */}
                        <div className="text-black my-10 ">
                            <div className="flex justify-between items-center w-full">
                                {/* Authorized Signatory */}
                                <div className="flex flex-col items-center ">
                                    <div style={{ width: '80px', height: '50px' }}>
                                        <img src={data?.signatory} alt="Authorized Signature" style={{ width: '100%', height: 'auto' }} />
                                    </div>
                                    <div className="mt-2 mb-4 w-full flex justify-center">
                                        <div className='border-b-2 border-dotted w-full border-black'></div>
                                    </div>
                                    <div style={{ fontSize: "14px" }}>AUTHORIZED SIGNATORY</div>
                                </div>

                                {/* Partner Code */}
                                <div className="flex flex-col items-center">
                                    <div className="text-lg font-bold mb-1">{userKycData.unique_id}</div>
                                    <div className="mt-2 mb-4 w-full flex justify-center">
                                        <div className='border-b-2 border-dotted w-full border-black'></div>
                                    </div>
                                    <div style={{ fontSize: "14px" }}>PARTNER CODE</div>
                                </div>

                                {/* Valid Upto */}
                                <div className="flex flex-col items-center">
                                    <div className="text-lg font-bold mb-1">{expiryDate()}</div>
                                    <div className="mt-2 mb-4 w-full flex justify-center">
                                        <div className='border-b-2 border-dotted w-full border-black'></div>
                                    </div>
                                    <div style={{ fontSize: "14px" }}>VALID UPTO</div>
                                </div>

                                {/* Powered By */}
                                <div className="flex flex-col items-center">
                                    <div style={{ fontSize: "14px", marginBottom: "6px" }}>POWERED BY</div>
                                    <img src={data.logo} alt="logo" style={{ width: '60px', height: 'auto' }} />
                                </div>
                            </div>
                        </div>

                        {/* Decorative Elements */}
                        <img src="/cert-top.png" className="absolute -top-6 -right-4" width={200} height={80} />
                        <img src="/cert-bottom.png" className="absolute -bottom-6 -left-4" width={200} height={80} />
                    </div>
                </div>
            </div>

        </div>
    );
}

export default Certificate;
